@@ -5,7 +5,6 @@ from typing import Callable, List, Optional, TYPE_CHECKING
 from discord import (
     Embed,
     Emoji,
-    Message,
     RawReactionActionEvent,
     Reaction,
 )
@@ -56,7 +55,8 @@ class PaginatedMenu(ButtonMenu):
         return getattr(self, '_timeout_page', None)
 
     def set_timeout_page(self, embed: Embed) -> 'PaginatedMenu':
-        """Sets the function that will be called when a menu is cancelled. Returns itself for fluent-style chaining.
+        """Sets the function that will be called when the `timeout` event runs. Returns itself for fluent-style
+        chaining.
 
         :param embed: Defines which page to display.
         :rtype: :class:`PaginatedMenu`
@@ -157,7 +157,7 @@ class PaginatedMenu(ButtonMenu):
                 self.input = await self._get_input()
 
                 # this will be true when input handles a timeout event
-                if not self.output:
+                if (not self.output) or (not self.active) or (self.output and self.persist and not self.active):
                     return
 
                 if self.output and isinstance(self.output.channel, GuildChannel):
@@ -169,37 +169,6 @@ class PaginatedMenu(ButtonMenu):
             await self._safe_clear_reactions()
 
     # Internal Methods
-    async def _get_input(self) -> Optional[Message]:
-        """Waits for a user reaction input event and returns the message object."""
-        tasks = [
-            asyncio.create_task(task())
-            for task in [self._get_reaction_add, self._get_reaction_remove, self._shortcircuit]
-        ]
-
-        done, pending = await asyncio.wait(tasks, return_when=asyncio.FIRST_COMPLETED, timeout=self.timeout)
-
-        # if all tasks are still pending, we force a timeout by manually calling cleanup methods
-        if len(pending) == len(tasks):
-            await self._timeout_menu()
-        else:
-            if not self.active:
-                self.kill_tasks(pending)
-
-            for future in done:
-                result = future.result()
-                if result:
-                    return result
-                else:
-                    return
-
-        self.kill_tasks(pending)
-
-    @staticmethod
-    def kill_tasks(pending: List[asyncio.Task]):
-        """Clears all remaining tasks in the task queue."""
-        for task in pending:
-            task.cancel()
-
     def _get_check(self) -> Callable:
         """Returns a check predicate based on detected buttons. Using the standard button list uses a
         simpler, and faster, predicate. Using custom buttons has to iterate over buttons to ensure they
@@ -214,17 +183,27 @@ class PaginatedMenu(ButtonMenu):
 
         return check
 
-    async def _get_reaction_add(self) -> 'Button':
+    async def _get_reaction_add(self) -> Optional['Button']:
         """Waits for a user reaction add event and returns the event object."""
         check = self._get_check()
-        reaction_event = await self.ctx.bot.wait_for('raw_reaction_add', check=check)
+        try:
+
+            reaction_event = await self.ctx.bot.wait_for('raw_reaction_add', check=check)
+
+        except AttributeError:
+            return
 
         return reaction_event.emoji
 
-    async def _get_reaction_remove(self) -> 'Button':
+    async def _get_reaction_remove(self) -> Optional['Button']:
         """Waits for a user reaction remove event and returns the event object."""
         check = self._get_check()
-        reaction_event = await self.ctx.bot.wait_for('raw_reaction_remove', check=check)
+
+        try:
+            reaction_event = await self.ctx.bot.wait_for('raw_reaction_remove', check=check)
+
+        except AttributeError:
+            return
 
         return reaction_event.emoji
 
@@ -268,7 +247,7 @@ class PaginatedMenu(ButtonMenu):
         transitions = [
             self.to_first,
             self.previous,
-            self.close,
+            self._cancel_menu,
             self.next,
             self.to_last,
         ]
